package com.fs.store.controller;

import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.domain.entity.SysUser;
import com.fs.common.core.page.TableDataInfo;
import com.fs.core.security.SecurityUtils;
import com.fs.store.param.FsStoreOrderAuditParam;
import com.fs.store.param.FsStoreOrderAuditReviewParam;
import com.fs.store.service.IFsStoreOrderAuditService;
import com.fs.store.vo.FsStoreOrderAuditVO;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping("/store/storeOrderAudit")
@AllArgsConstructor
public class FsStoreOrderAuditController extends BaseController {

    private final IFsStoreOrderAuditService fsStoreOrderAuditService;

    @PreAuthorize("@ss.hasAnyPermi('store:storeOrderAudit:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreOrderAuditParam param) {
        startPage();
        List<FsStoreOrderAuditVO> list = fsStoreOrderAuditService.selectStoreOrderAuditVOList(param);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasAnyPermi('store:storeOrderAudit:audit')")
    @PostMapping("/audit")
    public AjaxResult audit(@Valid @RequestBody FsStoreOrderAuditReviewParam param) {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        fsStoreOrderAuditService.audit(param, user.getUserId(), true);
        return AjaxResult.success();
    }
}
