package com.fs.course.service.impl;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.course.mapper.FsUserCoursePeriodMapper;
import com.fs.store.mapper.FsUserMapper;
import com.google.common.collect.Lists;
import lombok.AllArgsConstructor;
import org.apache.ibatis.session.ExecutorType;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.course.mapper.FsUserWatchStatisticsMapper;
import com.fs.course.domain.FsUserWatchStatistics;
import com.fs.course.service.IFsUserWatchStatisticsService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 会员看课统计-按营期统计Service业务层处理
 *
 * @author fs
 * @date 2025-06-16
 */
@Service
@AllArgsConstructor
public class FsUserWatchStatisticsServiceImpl extends ServiceImpl<FsUserWatchStatisticsMapper, FsUserWatchStatistics> implements IFsUserWatchStatisticsService {

    private final FsUserCoursePeriodMapper fsUserCoursePeriodMapper;

    private final FsUserMapper fsUserMapper;

    @Autowired
    private SqlSessionFactory sqlSessionFactory;

    /**
     * 查询会员看课统计-按营期统计
     *
     * @param id 会员看课统计-按营期统计主键
     * @return 会员看课统计-按营期统计
     */
    @Override
    public FsUserWatchStatistics selectFsUserWatchStatisticsById(Long id)
    {
        return baseMapper.selectFsUserWatchStatisticsById(id);
    }

    /**
     * 查询会员看课统计-按营期统计列表
     *
     * @param fsUserWatchStatistics 会员看课统计-按营期统计
     * @return 会员看课统计-按营期统计
     */
    @Override
    public List<FsUserWatchStatistics> selectFsUserWatchStatisticsList(FsUserWatchStatistics fsUserWatchStatistics)
    {
        return baseMapper.selectFsUserWatchStatisticsList(fsUserWatchStatistics);
    }

    /**
     * 新增会员看课统计-按营期统计
     *
     * @param fsUserWatchStatistics 会员看课统计-按营期统计
     * @return 结果
     */
    @Override
    public int insertFsUserWatchStatistics(FsUserWatchStatistics fsUserWatchStatistics)
    {
        return baseMapper.insertFsUserWatchStatistics(fsUserWatchStatistics);
    }

    /**
     * 修改会员看课统计-按营期统计
     *
     * @param fsUserWatchStatistics 会员看课统计-按营期统计
     * @return 结果
     */
    @Override
    public int updateFsUserWatchStatistics(FsUserWatchStatistics fsUserWatchStatistics)
    {
        return baseMapper.updateFsUserWatchStatistics(fsUserWatchStatistics);
    }

    /**
     * 批量删除会员看课统计-按营期统计
     *
     * @param ids 需要删除的会员看课统计-按营期统计主键
     * @return 结果
     */
    @Override
    public int deleteFsUserWatchStatisticsByIds(Long[] ids)
    {
        return baseMapper.deleteFsUserWatchStatisticsByIds(ids);
    }

    /**
     * 删除会员看课统计-按营期统计信息
     *
     * @param id 会员看课统计-按营期统计主键
     * @return 结果
     */
    @Override
    public int deleteFsUserWatchStatisticsById(Long id)
    {
        return baseMapper.deleteFsUserWatchStatisticsById(id);
    }

    @Override
    @Transactional
    public void insertStatistics() {
        // 1、获取统计结果
        // 获取所有营期
//        FsUserCoursePeriod periodParam = new FsUserCoursePeriod();
//        List<FsUserCoursePeriod> fsUserCoursePeriods = fsUserCoursePeriodMapper.selectFsUserCoursePeriodList(periodParam);

        //获取会员数量和新增会员数量
        List<FsUserWatchStatistics> userTotal = fsUserMapper.selectFsUserTotal();
        FsUserWatchStatistics userTotalStatistics = new FsUserWatchStatistics();
        if(!userTotal.isEmpty()){
            userTotalStatistics = userTotal.get(0);
        }

        // 获取看课统计
        List<FsUserWatchStatistics> courseWatchStatistics = baseMapper.getCourseWatchStatistics();

        // 转化map
        Map<Long, FsUserWatchStatistics> watchStatisticsMap = courseWatchStatistics.stream()
                .collect(Collectors.toMap(
                        FsUserWatchStatistics::getPeriodId,
                        Function.identity()
                ));
        // 组装数据
//        List<FsUserWatchStatistics> list = fsUserCoursePeriods.stream().map(v -> {
//            FsUserWatchStatistics fsUserWatchStatistics = new FsUserWatchStatistics();
//            BeanUtils.copyProperties(v, fsUserWatchStatistics);
//            FsUserWatchStatistics count = watchStatisticsMap.getOrDefault(v.getPeriodId(), fsUserWatchStatistics);
//            fsUserWatchStatistics.setWatchNum(count.getWatchNum());
//            fsUserWatchStatistics.setCompleteWatchNum(count.getCompleteWatchNum());
//            fsUserWatchStatistics.setCompleteWatchRate(count.getCompleteWatchRate());
//            return fsUserWatchStatistics;
//        }).collect(Collectors.toList());
        for (FsUserWatchStatistics courseWatchStatistic : courseWatchStatistics) {
            FsUserWatchStatistics count = watchStatisticsMap.getOrDefault(courseWatchStatistic.getPeriodId(), courseWatchStatistic);
            // 单独set，不用copy，避免copy出来的结果被前面的覆盖
            courseWatchStatistic.setUserNum(userTotalStatistics.getUserNum() != null ? userTotalStatistics.getUserNum():0);
            courseWatchStatistic.setNewUserNum(userTotalStatistics.getNewUserNum() != null ? userTotalStatistics.getNewUserNum():0);
            courseWatchStatistic.setWatchNum(count.getWatchNum() !=null ? count.getWatchNum():0);
            courseWatchStatistic.setCompleteWatchNum(count.getCompleteWatchNum() != null ? count.getCompleteWatchNum():0);
            courseWatchStatistic.setCompleteWatchRate(count.getCompleteWatchRate() != null ? count.getCompleteWatchRate(): BigDecimal.ZERO);
            courseWatchStatistic.setCreateTime(new Date());
            courseWatchStatistic.setUpdateTime(new Date());
        }

        //2、分批次插入数据
        this.batchInsert(courseWatchStatistics);
    }

    private void batchInsert(List<FsUserWatchStatistics> list) {
        // 分批次处理，一次提交500条
        List<List<FsUserWatchStatistics>> batches = Lists.partition(list, 500);
        batches.forEach(batch -> {
            SqlSession sqlSession = sqlSessionFactory.openSession(ExecutorType.BATCH);
            try {
                FsUserWatchStatisticsMapper mapper = sqlSession.getMapper(FsUserWatchStatisticsMapper.class);
                batch.forEach(mapper::insertFsUserWatchStatisticsTask);
                sqlSession.commit();
            } finally {
                sqlSession.close();
            }
        });
    }
}
