package com.fs.sop.service;

import com.fs.common.core.domain.R;
import com.fs.qw.domain.QwSopUpdateStatus;
import com.fs.sop.domain.QwSop;
import com.fs.sop.params.QwSopAutoTime;
import com.fs.sop.params.QwSopEditQwUserParam;
import com.fs.sop.vo.QwSopTask;
import com.fs.sop.vo.SopVoiceListVo;

import java.io.IOException;
import java.util.List;

/**
 * 企微sopService接口
 *
 * @author fs
 * @date 2024-07-31
 */
public interface IQwSopService
{

    List<QwSopTask> getQwSopTaskList();
    /**
     * 查询企微sop
     *
     * @param id 企微sop主键
     * @return 企微sop
     */
    public QwSop selectQwSopById(String id);


    /**
     * 查询企微sop列表
     *
     * @param qwSop 企微sop
     * @return 企微sop集合
     */
    public List<QwSop> selectQwSopList(QwSop qwSop);

    public List<QwSop> selectQwSopMyList(QwSop qwSop);

    /**
     * 新增企微sop
     *
     * @param qwSop 企微sop
     * @return 结果
     */
    public int insertQwSop(QwSop qwSop);

    /**
     * 修改企微sop
     *
     * @param qwSop 企微sop
     * @return 结果
     */
    public R updateQwSop(QwSop qwSop);
    public int updateAutoSopTime(QwSopAutoTime param);
    public R  updateSopStatus(QwSopUpdateStatus param);

    /**
     * 批量删除企微sop
     *
     * @param ids 需要删除的企微sop主键集合
     * @return 结果
     */
    public int deleteQwSopByIds(String[] ids);

    /**
     * 删除企微sop信息
     *
     * @param id 企微sop主键
     * @return 结果
     */
    public int deleteQwSopById(String id);

    /**
     * 新版sop-检查可以执行的sop规则
     */
    public void checkSopRuleTime();

    /**
    * 更新执行状态
    */
    public R updateStatusQwSopByIds(String[] ids);

    public R updateMediaImage(String url,String  cropId ) throws IOException;


    List<QwSop> selectAiChatQwSopList(QwSop qwSop);

    R updateSopQwUser(QwSopEditQwUserParam param);

    List<SopVoiceListVo> getSopVoiceList(String id);

    List<QwSop> selectWxSop();

}
