package com.fs.store.service;

import com.fs.store.domain.FsHomeArticleCategory;
import com.fs.store.param.home.HomeArticleCategoryPageParam;
import com.fs.store.vo.home.HomeArticleCategoryListVO;

import java.util.List;

/**
 * 期刊分类Service接口
 *
 * @author fs
 * @date 2025-05-21
 */
public interface IFsHomeArticleCategoryService
{
    /**
     * 查询期刊分类
     *
     * @param categoryId 期刊分类ID
     * @return 期刊分类
     */
    public FsHomeArticleCategory selectFsHomeArticleCategoryById(Long categoryId);

    /**
     * 查询期刊分类列表
     *
     * @param fsHomeArticleCategory 期刊分类
     * @return 期刊分类集合
     */
    public List<FsHomeArticleCategory> selectFsHomeArticleCategoryList(FsHomeArticleCategory fsHomeArticleCategory);

    /**
     * 新增期刊分类
     *
     * @param fsHomeArticleCategory 期刊分类
     * @return 结果
     */
    public int insertFsHomeArticleCategory(FsHomeArticleCategory fsHomeArticleCategory);

    /**
     * 修改期刊分类
     *
     * @param fsHomeArticleCategory 期刊分类
     * @return 结果
     */
    public int updateFsHomeArticleCategory(FsHomeArticleCategory fsHomeArticleCategory);

    /**
     * 批量删除期刊分类
     *
     * @param categoryIds 需要删除的期刊分类ID
     * @return 结果
     */
    public int deleteFsHomeArticleCategoryByIds(Long[] categoryIds);

    /**
     * 删除期刊分类信息
     *
     * @param categoryId 期刊分类ID
     * @return 结果
     */
    public int deleteFsHomeArticleCategoryById(Long categoryId);

    /**
     * 根据搜索条件获取分页的文章分类
     * @param param 入参
     * @return list
     */
    List<HomeArticleCategoryListVO> selectHomeArticleCategoryPageList(HomeArticleCategoryPageParam param);
}
