package com.fs.store.service;

import com.fs.store.domain.FsHomeArticle;
import com.fs.store.param.home.HomeArticlePageParam;
import com.fs.store.vo.home.HomeArticleDetailsVO;
import com.fs.store.vo.home.HomeArticleListVO;

import java.util.List;

/**
 * 期刊Service接口
 *
 * @author fs
 * @date 2025-05-22
 */
public interface IFsHomeArticleService
{
    /**
     * 查询期刊
     *
     * @param articleId 期刊ID
     * @return 期刊
     */
    public FsHomeArticle selectFsHomeArticleById(Long articleId);

    /**
     * 查询期刊列表
     *
     * @param fsHomeArticle 期刊
     * @return 期刊集合
     */
    public List<FsHomeArticle> selectFsHomeArticleList(FsHomeArticle fsHomeArticle);

    /**
     * 新增期刊
     *
     * @param fsHomeArticle 期刊
     * @return 结果
     */
    public int insertFsHomeArticle(FsHomeArticle fsHomeArticle);

    /**
     * 修改期刊
     *
     * @param fsHomeArticle 期刊
     * @return 结果
     */
    public int updateFsHomeArticle(FsHomeArticle fsHomeArticle);

    /**
     * 批量删除期刊
     *
     * @param articleIds 需要删除的期刊ID
     * @return 结果
     */
    public int deleteFsHomeArticleByIds(Long[] articleIds);

    /**
     * 删除期刊信息
     *
     * @param articleId 期刊ID
     * @return 结果
     */
    public int deleteFsHomeArticleById(Long articleId);

    /**
     * 根据分类id获取文章
     * @param fsHomeArticle 入参
     * @return list
     */
    List<HomeArticleListVO> selectHomeArticlePageList(HomeArticlePageParam fsHomeArticle);

    /**
     * 获取文章详情
     * @param articleId 文章id
     * @return
     */
    HomeArticleDetailsVO getHomeArticleDetailsById(Long articleId);

}
